lilypondparsertools.Music
=========================

.. abjad-lineage:: abjad.tools.lilypondparsertools.Music.Music

.. autoclass:: abjad.tools.lilypondparsertools.Music.Music

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.lilypondparsertools.Music.Music.construct
      ~abjad.tools.lilypondparsertools.Music.Music.__eq__
      ~abjad.tools.lilypondparsertools.Music.Music.__format__
      ~abjad.tools.lilypondparsertools.Music.Music.__ne__
      ~abjad.tools.lilypondparsertools.Music.Music.__repr__

Bases
-----

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Methods
-------

.. automethod:: abjad.tools.lilypondparsertools.Music.Music.construct
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.lilypondparsertools.Music.Music.__eq__
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.Music.Music.__format__
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.Music.Music.__ne__
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.Music.Music.__repr__
   :noindex:
